summaryrefslogtreecommitdiffstats
path: root/controller-api
diff options
context:
space:
mode:
authorValerij Fredriksen <valerijf@yahooinc.com>2023-06-01 16:06:37 +0200
committerValerij Fredriksen <valerijf@yahooinc.com>2023-06-01 16:06:37 +0200
commitb4da5723743f8ee547f0f9f0acd57652447df53b (patch)
treec8c10ae2ef351b65ad589a143f9d34c485e0a232 /controller-api
parent4cae2ecf6c9c5ac7f329a112451909d0f7ac3950 (diff)
Fix exclave condition
Diffstat (limited to 'controller-api')
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java8
1 files changed, 6 insertions, 2 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java
index 6cdb197b307..f2cd55b88b2 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java
@@ -39,8 +39,12 @@ public interface ZoneRegistry {
/** Returns whether cloudAccount in this system supports given zone */
boolean hasZone(ZoneId zoneId, CloudAccount cloudAccount);
- /** Returns whether the given cloud account is an enclave */
- boolean isEnclave(CloudAccount cloudAccount);
+ /** Returns whether the given cloud account is not one of the system accounts */
+ boolean isExternal(CloudAccount cloudAccount);
+
+ default boolean isExclave(CloudAccount cloudAccount) {
+ return system().isPublic() && isExternal(cloudAccount);
+ }
/** Returns a list containing the id of all zones in this registry */
ZoneFilter zones();